<html>
<head>
<title>my diary...</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<style type="text/css">
<!--
body {  background-color: #99CCFF; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px}
.lightblue {  background-color: #D2E9FF; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; border: 1px #999999 dashed; text-align: justify; padding-top: 5px; padding-right: 5px; padding-bottom: 5px; padding-left: 5px}
-->
</style>
</head>

<body bgcolor="#FFFFFF" text="#000000" tracingsrc="../simpleblue.png" tracingopacity="26">

<table width="475" border="0" cellpadding="0" cellspacing="0" mm:layoutgroup="true">
  <tr> 
    <td width="24" height="12"></td>
    <td width="197"></td>
    <td width="254"></td>
  </tr>
  <tr> 
    <td height="351"></td>
    <td valign="top" colspan="2" class="lightblue"> 
      <p>
<tmpl_loop older_entries>
<li><tmpl_var date> - <a href="<tmpl_var escape=url name=filename>"><tmpl_var escape=html name=short_name></a> (<tmpl_var wc> words)
</tmpl_loop>

		
<p></p>
<hr>
<p><tmpl_var total_words> words total in this diary</p>

      
    </td>
  </tr>
</table>
</body>
</html>
