<html>
<head>
<title>my diary...</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<style type="text/css">
<!--
body {  background-color: #99CCFF; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px}
.lightblue {  background-color: #D2E9FF; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; border: 1px #999999 dashed; text-align: justify; padding-top: 5px; padding-right: 5px; padding-bottom: 5px; padding-left: 5px}
-->
</style>
</head>

<body bgcolor="#FFFFFF" text="#000000" tracingsrc="../simpleblue.png" tracingopacity="26">

<table width="475" border="0" cellpadding="0" cellspacing="0" mm:layoutgroup="true">
  <tr> 
    <td width="24" height="12"></td>
    <td width="197"></td>
    <td width="254"></td>
  </tr>
  <tr> 
    <td height="28"></td>
    <td colspan="2" valign="top" class="lightblue">
	i'm feeling blue... oh so blue... 
	[ <a href="<!--tmpl_var name="prev"-->">Previous</a> ] 
        [ <a href="<!--tmpl_var name="next"-->">Next</a> ] 
        [ <a href="older.html">Older</a> ]
</td>
  </tr>
  <tr> 
    <td height="14"></td>
    <td></td>
    <td></td>
  </tr>
  <tr> 
    <td height="29"></td>
    <td></td>
    <td valign="top" class="lightblue"><b><!--tmpl_var name="short_name"--></b> - <!--tmpl_var name="date"--> (<!--tmpl_var name="wc"--> words)</td>
  </tr>
  <tr> 
    <td height="14"></td>
    <td></td>
    <td></td>
  </tr>
  <tr> 
    <td height="351"></td>
    <td valign="top" colspan="2" class="lightblue"><p><!--tmpl_var name="entry"-->


<!-- comments only appear if there are any. If you don't
     want comments to show up, leave this section out -->

<tmpl_if comments>
<hr>
<p><b>comments that people have left:</b></p>
<p>
<tmpl_loop comments>
<b><tmpl_var who></b> (<tmpl_var date>): <tmpl_var entry><p>
</tmpl_loop>

</tmpl_if>


<!-- a little form for adding a comment -->
<form action="post-comment" method="post">
        <table class="lightblue">
		<tr>
            <td colspan="2"><b>Add a comment:</b> (it will be posted here, and 
              anyone could read it)</td>
          </tr>
          <tr> 
            <td> 
              <p>Name:</p>
            </td>
            <td> 
              <input name="name">
            </td>
          <tr> 
            <td> 
              <p>Entry:</p>
            </td>
            <td> 
              <textarea name="comment" rows=5 cols=30></textarea>
            </td>
          </tr>
          <tr> 
            <td>&nbsp;</td>
            <td> 
              <input type="submit" value="post">
            </td>
          </tr>
          <input type="hidden" name="filename" value="<tmpl_var filename>">
        </table>
        <p>&nbsp;</p>
      </form></td>
  </tr>
</table>
</body>
</html>
